Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(98)

Unified Diff: ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h

Issue 2672823003: Rename ReadingListViewController to ReadingListCollectionViewController (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h
diff --git a/ios/chrome/browser/ui/reading_list/reading_list_view_controller.h b/ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h
similarity index 51%
rename from ios/chrome/browser/ui/reading_list/reading_list_view_controller.h
rename to ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h
index 4ff7fa1cdc6363c52fb887d712b1c1aabf06e407..d4b201febad4944ae7d1942146f0d87b3b496f40 100644
--- a/ios/chrome/browser/ui/reading_list/reading_list_view_controller.h
+++ b/ios/chrome/browser/ui/reading_list/reading_list_collection_view_controller.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_VIEW_CONTROLLER_H_
-#define IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_VIEW_CONTROLLER_H_
+#ifndef IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_COLLECTION_VIEW_CONTROLLER_H_
+#define IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_COLLECTION_VIEW_CONTROLLER_H_
#import "ios/chrome/browser/ui/collection_view/collection_view_controller.h"
@@ -15,41 +15,47 @@ namespace favicon {
class LargeIconService;
}
+@class ReadingListCollectionViewController;
@class ReadingListCollectionViewItem;
class ReadingListDownloadService;
class ReadingListModel;
-@class ReadingListViewController;
@class TabModel;
// Delegate for the ReadingListViewController, managing the visibility of the
// toolbar, dismissing the Reading List View and opening elements.
-@protocol ReadingListViewControllerDelegate<NSObject>
+@protocol ReadingListCollectionViewControllerDelegate<NSObject>
// Whether the collection has items.
-- (void)readingListViewController:
- (ReadingListViewController*)readingListViewController
- hasItems:(BOOL)hasItems;
+- (void)readingListCollectionViewController:
+ (ReadingListCollectionViewController*)
+ readingListCollectionViewController
+ hasItems:(BOOL)hasItems;
// Dismisses the Reading List View.
-- (void)dismissReadingListViewController:
- (ReadingListViewController*)readingListViewController;
+- (void)dismissReadingListCollectionViewController:
+ (ReadingListCollectionViewController*)readingListCollectionViewController;
// Displays the context menu for the |readingListItem|. The |menuLocation| is
// the anchor of the context menu in the
-// readingListViewController.collectionView coordinates.
-- (void)
-readingListViewController:(ReadingListViewController*)readingListViewController
-displayContextMenuForItem:(ReadingListCollectionViewItem*)readingListItem
- atPoint:(CGPoint)menuLocation;
+// readingListCollectionViewController.collectionView coordinates.
+- (void)readingListCollectionViewController:
+ (ReadingListCollectionViewController*)
+ readingListCollectionViewController
+ displayContextMenuForItem:
+ (ReadingListCollectionViewItem*)readingListItem
+ atPoint:(CGPoint)menuLocation;
// Opens the entry corresponding to the |readingListItem|.
- (void)
-readingListViewController:(ReadingListViewController*)readingListViewController
- openItem:(ReadingListCollectionViewItem*)readingListItem;
+readingListCollectionViewController:
+ (ReadingListCollectionViewController*)readingListCollectionViewController
+ openItem:
+ (ReadingListCollectionViewItem*)readingListItem;
@end
-@interface ReadingListViewController
+@interface ReadingListCollectionViewController
: CollectionViewController<ReadingListToolbarActions>
- (instancetype)initWithModel:(ReadingListModel*)model
@@ -61,7 +67,8 @@ readingListViewController:(ReadingListViewController*)readingListViewController
- (instancetype)initWithStyle:(CollectionViewControllerStyle)style
NS_UNAVAILABLE;
-@property(nonatomic, weak) id<ReadingListViewControllerDelegate> delegate;
+@property(nonatomic, weak) id<ReadingListCollectionViewControllerDelegate>
+ delegate;
@property(nonatomic, readonly) ReadingListModel* readingListModel;
@property(nonatomic, readonly) favicon::LargeIconService* largeIconService;
@property(nonatomic, readonly)
@@ -75,4 +82,4 @@ readingListViewController:(ReadingListViewController*)readingListViewController
@end
-#endif // IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_VIEW_CONTROLLER_H_
+#endif // IOS_CHROME_BROWSER_UI_READING_LIST_READING_LIST_COLLECTION_VIEW_CONTROLLER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -15,41 +15,47 @@ namespace favicon {
-// Delegate for the ReadingListViewController, managing the visibility of the
+// Delegate for the ReadingListCollectionViewController, managing the visibility
+// of the
// toolbar, dismissing the Reading List View and opening elements.